.. Copyright (c) 2016, Johan Mabille, Sylvain Corlay and Wolf Vollprecht

   Distributed under the terms of the BSD 3-Clause License.

   The full license is in the file LICENSE, distributed with this software.

Functions and generators
========================

.. toctree::

   xfunction
   xreducer
   xaccumulator
   xgenerator
   xbuilder
   xmanipulation
   xsort
   xset_operation
   xrandom
   xhistogram
   xpad
